var node_itk = require('node-itk');

var image = new node_itk.NodeImage('rgb',2);

console.log('pixel:'+image.GetPixelType());
console.log(image.GetDimension());

image.Read('rgb',2,'./Data/Desert.jpg');
image.Write('rgb.jpg');
image.Cast('uchar');
image.Write('uchar.tiff');
image.ScaleCast('rgb');
image.Write('rgb2.tiff');

image.ReadSeriesRE('rgb','vew00[1-9].jpg', 0, './');
image.Write('s.tiff');
image.ScaleCast('short');
image.Write('s2.tiff');
image.ScaleCast('uchar');
image.Write('s3.tiff');